@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::I18n;
-$Test::BDD::Cucumber::I18n::VERSION = '0.20';
+$Test::BDD::Cucumber::I18n::VERSION = '0.21';
 =head1 NAME
 
 Test::BDD::Cucumber::I18N - Internationalization
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ sub _initialize_language_definitions_from_shared_json_file {
 }
 
 sub languages {
-    return keys $langdefs;
+    return keys %$langdefs;
 }
 
 sub has_language {
